@@ -395,6 +395,30 @@ class PanXapi:
                         lines.append(elem2.text)
             return '\n'.join(lines) if lines else None
 
+        # multi-config responses have nested response tags under the
+        # main response tag
+        path = './response'
+        elem = self.element_root.findall(path)
+        if len(elem) > 0:
+            self._log(DEBUG2, 'path: %s', path)
+            for resp in elem:
+                attributes = ''
+                for x in ['status', 'code', 'id']:
+                    if x in resp.attrib:
+                        attributes += '%s="%s" ' % (x, resp.attrib[x])
+                msg = resp.find('./msg')
+                if msg is None:
+                    lines.append(attributes.rstrip())
+                    continue
+                line = msg.find('./line')
+                if line is not None and line.text is not None:
+                    lines.append(attributes + line.text)
+                elif msg.text is not None:
+                    lines.append(attributes + msg.text)
+                elif attributes:
+                    lines.append(attributes.rstrip())
+            return '\n'.join(lines) if lines else None
+
         return None
 
     # XXX store tostring() results?
@@ -502,7 +526,6 @@ class PanXapi:
             if hasattr(error, 'code'):
                 msg += ' code: %s' % error.code
             if hasattr(error, 'reason'):
-                self._rome_warning(str(error.reason))
                 msg += ' reason: %s' % error.reason
             if not (hasattr(error, 'code') or hasattr(error, 'reason')):
                 msg += ' unknown error (Kevin heart Python)'
@@ -514,19 +537,6 @@ class PanXapi:
 
         return response
 
-    def _rome_warning(self, reason):
-        # "Connection reset by peer" or
-        # "EOF occurred in violation of protocol"
-        # may indicate no TLS 1.[12]
-        if (('Errno 54' in reason or
-                'EOF occurred in violation of protocol' in reason) and
-                hasattr(ssl, 'OPENSSL_VERSION_NUMBER') and
-                ssl.OPENSSL_VERSION_NUMBER < 0x1000100):
-            x = 'WARNING: Your SSL (%s) may not support TLS 1.1.' % \
-                ssl.OPENSSL_VERSION
-            x += ' PAN-OS 8.0 does not allow TLS 1.0 connections by default.'
-            self._log(DEBUG1, x)
-
     def __set_api_key(self):
         if self.api_key is None:
             self.keygen()
@@ -734,6 +744,14 @@ class PanXapi:
             query['element'] = element
         self.__type_config('override', query, extra_qs)
 
+    def multi_config(self, element=None, strict=None, extra_qs=None):
+        query = {}
+        if element is not None:
+            query['element'] = element
+        if strict is not None:
+            query['strict-transactional'] = 'yes' if strict else 'no'
+        self.__type_config('multi-config', query, extra_qs)
+
     def __type_config(self, action, query, extra_qs=None):
         self.__set_api_key()
         self.__clear_response()
@@ -1097,6 +1115,8 @@ class PanXapi:
             query['reportname'] = reportname
         if vsys is not None:
             query['vsys'] = vsys
+        if self.serial is not None:
+            query['target'] = self.serial
         if extra_qs is not None:
             query = self.__merge_extra_qs(query, extra_qs)
 
@@ -1130,6 +1150,8 @@ class PanXapi:
         query['action'] = 'get'
         query['key'] = self.api_key
         query['job-id'] = job.text
+        if self.serial is not None:
+            query['target'] = self.serial
         self._log(DEBUG2, 'report job: %s', job.text)
 
         start_time = time.time()
